use axum::{Extension, Json};
use domain::{dto::account::{AuthenticateGooleAccountReq, AuthenticateWithPassword, RefreshToken}, vo::account::{LoginAccount, RefreshTokenResult}};
use library::{context::{Context, WhiteContext}, res::{response::{ ResData, ResResult}, validator}};

/// google账号登录
pub async fn authenticate_google(
    Extension(context): Extension<WhiteContext>,
    Json(req): Json<AuthenticateGooleAccountReq>
) -> ResResult<ResData<LoginAccount>> {
    validator::validate_params(&req, context.get_lang_tag())?;
    service::account::authenticate_google(context, req).await
}

/// 账号密码登录
pub async fn authenticate_with_password(
    Extension(context): Extension<WhiteContext>,
    Json(req): Json<AuthenticateWithPassword>
) -> ResResult<ResData<LoginAccount>> {
    validator::validate_params(&req, context.get_lang_tag())?;
    service::sys_account::authenticate_with_password(context, req).await
}

/// 刷新token
pub async fn refresh_token(
    Extension(context): Extension<Context>,
    Json(refresh_token): Json<RefreshToken>
) -> ResResult<ResData<RefreshTokenResult>> {
    tracing::debug!("刷新token, {:?}", context);
    validator::validate_params(&refresh_token, "")?;
    service::account::refresh_token(context, refresh_token.token).await
}

/// 添加管理员账号
pub async fn add_account() -> ResResult<ResData<()>> {
    service::sys_account::add_account().await
}