use axum::extract::Query;
use axum::{Extension, Json};
use library::context::Context;
use domain::dto::feedback::FeedbackAdd;
use domain::dto::pageable::PageParams;
use domain::entities::feedback::Feedback;
use library::res::pageable::Pageable;
use library::res::response::{ResData, ResResult};
use library::res::validator;

/// 添加反馈信息
pub async fn add_feedback(
    Extension(context): Extension<Context>,
    Json(req): Json<FeedbackAdd>
) -> ResResult<ResData<()>> {
    validator::validate_params(&req, context.get_lang_tag())?;
    service::feedback::add_feedback(context, req).await
}

/// 获取反馈信息列表
pub async fn get_feedback_list_by_page(
    Extension(context): Extension<Context>,
    Query(page_params): Query<PageParams>
) -> ResResult<ResData<Pageable<Feedback>>> {
    service::feedback::get_feedback_list_by_page(context, page_params.page.unwrap(), page_params.page_size.unwrap()).await
}