use std::collections::HashMap;

use lazy_static::lazy_static;

use crate::message_ids::{
    ACCOUNT_DISABLED, ACCOUNT_NO_PERMISSION, HELLO, INCORRECT_USERNAME_OR_PASSWORD, INVALID_TOKEN, VALIDATE_ACCOUNT_ID_TOKEN_REQUIRED, VALIDATE_ACCOUNT_LANG_TAG_REQUIRED, VALIDATE_ACCOUNT_NAME_REQUIRED, VALIDATE_ACCOUNT_PASSWORD_REQUIRED, VALIDATE_FEEDBACK_CONTENT_REQUIRED, VALIDATE_PAGEABLE_PAGE_REQUIRED, VALIDATE_PAGEABLE_PAGE_SIZE_REQUIRED
};

pub const LANGUAGE_ID: &str = "zh-CN";

lazy_static! {
    pub static ref MESSAGE: HashMap<&'static str, &'static str> = {
        let mut map = HashMap::new();
        map.insert(HELLO, "你好 {}");
        map.insert(ACCOUNT_DISABLED, "账户已禁用");
        map.insert(ACCOUNT_NO_PERMISSION, "账户无权限");
        map.insert(INCORRECT_USERNAME_OR_PASSWORD, "用户名或密码错误");
        map.insert(INVALID_TOKEN, "无效令牌");

        map.insert(VALIDATE_FEEDBACK_CONTENT_REQUIRED, "反馈内容不能为空");
        map.insert(VALIDATE_ACCOUNT_NAME_REQUIRED, "用户名称不能为空");
        map.insert(VALIDATE_ACCOUNT_PASSWORD_REQUIRED, "密码不能为空");
        map.insert(VALIDATE_ACCOUNT_ID_TOKEN_REQUIRED, "用户ID Token不能为空");
        map.insert(VALIDATE_ACCOUNT_LANG_TAG_REQUIRED, "用户语言标识不能为空");
        map.insert(VALIDATE_PAGEABLE_PAGE_REQUIRED, "页码无效");
        map.insert(VALIDATE_PAGEABLE_PAGE_SIZE_REQUIRED, "每页数量无效");
        map
    };
}
