use task::google_iap;
use tokio_cron_scheduler::{JobScheduler, JobSchedulerError};

pub(crate) mod task;

/// 启动定时任务
pub async fn start() {
    match schedule().await {
        Ok(_) => tracing::info!("定时任务启动成功"),
        Err(err) => tracing::error!(error = ?err, "定时任务启动失败"),
    }
}

async fn schedule() -> Result<(), JobSchedulerError> {
    let mut scheduler = JobScheduler::new().await?;
    scheduler.init().await?;

    // 添加任务
    scheduler.add(google_iap::get_task()?).await?;

    // 添加关闭监听
    scheduler.set_shutdown_handler(Box::new(|| {
        Box::pin(async move {
            tracing::info!("定时任务已关闭");
        })
    }));
    
    // 启动任务
    scheduler.start().await?;
    Ok(())
}